@@ -12,7 +12,6 @@ import dill
 
 import deltalanguage.data_types.dotdf_capnp \
     as dotdf_capnp  # pylint: disable=E0401, disable=E0611
-from deltalanguage._utils import NamespacedName
 from deltalanguage.data_types import (DeltaTypeError,
                                       Optional,
                                       Int,
@@ -38,7 +37,12 @@ from deltalanguage.wiring._node_classes.migen_node import MigenNodeTemplate
 from deltalanguage.lib.hal import HardwareAbstractionLayerNode
 from deltalanguage.lib.quantum_simulators import (ProjectqQuantumSimulator,
                                                   QiskitQuantumSimulator)
-from deltalanguage.test._utils import assert_capnp_content_types, return_1
+
+from deltalanguage.test._lib import (add_non_const,
+                                     return_1_const,
+                                     multiplier,
+                                     MigenDUT)
+from deltalanguage.test._utils import assert_capnp_content_types
 
 
 class OpCacher():
@@ -63,7 +67,7 @@ class PortSerialisationTest(unittest.TestCase):
 
     def test_in_port_capnp(self):
         """Generate in port."""
-        in_port = InPort(NamespacedName("node_name", "index"),
+        in_port = InPort("index",
                          as_delta_type(int), None, 0)
         capnp_in_port = dotdf_capnp.InPort.new_message()
         in_port.capnp(capnp_in_port)
@@ -73,8 +77,7 @@ class PortSerialisationTest(unittest.TestCase):
 
     def test_in_port_capnp_optional(self):
         """Generate optional in port."""
-        in_port = InPort(NamespacedName("node_name", "index"),
-                         Optional(int), None, 0)
+        in_port = InPort("index", Optional(int), None, 0)
         capnp_in_port = dotdf_capnp.InPort.new_message()
         in_port.capnp(capnp_in_port)
         self.assertEqual(capnp_in_port.name, "index")
@@ -83,13 +86,13 @@ class PortSerialisationTest(unittest.TestCase):
 
     def test_in_port_capnp_wiring(self):
         """Generate wiring."""
-        in_port = InPort(NamespacedName("node_name", "index"),
-                         as_delta_type(int), None, 0)
+        n = RealNode(DeltaGraph(), [], name='node_name')
+        in_port = InPort("index", as_delta_type(int), n, 0)
         wire = dotdf_capnp.Wire.new_message()
         nodes = [dotdf_capnp.Node.new_message() for _ in range(3)]
         nodes[0].name = "fake_name"
         nodes[1].name = "fake_name"
-        nodes[2].name = "node_name"
+        nodes[2].name = n.full_name
         nodes[2].init("inPorts", 3)
         nodes[2].inPorts[0].name = "fake_name"
         nodes[2].inPorts[1].name = "index"
@@ -101,11 +104,11 @@ class PortSerialisationTest(unittest.TestCase):
 
     def test_in_port_capnp_wiring_direct(self):
         """In port has limit on port size."""
-        in_port = InPort(NamespacedName("node_name", "index"),
-                         as_delta_type(int), None, 1)
+        n = RealNode(DeltaGraph(), [], name='node_name')
+        in_port = InPort("index", as_delta_type(int), n, 1)
         wire = dotdf_capnp.Wire.new_message()
         nodes = [dotdf_capnp.Node.new_message()]
-        nodes[0].name = "node_name"
+        nodes[0].name = n.full_name
         nodes[0].init("inPorts", 1)
         nodes[0].inPorts[0].name = "index"
         in_port.capnp_wiring(nodes, wire)
@@ -115,8 +118,7 @@ class PortSerialisationTest(unittest.TestCase):
 
     def test_out_port_capnp(self):
         """Generate out port."""
-        out_port = OutPort(NamespacedName("node_name", "index"),
-                           as_delta_type(int), None, None)
+        out_port = OutPort("index", as_delta_type(int), None, None)
         capnp_out_port = dotdf_capnp.OutPort.new_message()
         out_port.capnp(capnp_out_port)
         self.assertEqual(capnp_out_port.name, "index")
@@ -124,22 +126,10 @@ class PortSerialisationTest(unittest.TestCase):
         with self.assertRaises(AttributeError):
             dummy = capnp_out_port.optional
 
-    def test_out_port_capnp_no_index(self):
-        """Generate out port when index not provided.
-        In this case, name should be empty string.
-        """
-        out_port = OutPort(NamespacedName("node_name", None),
-                           as_delta_type(int), None, None)
-        capnp_out_port = dotdf_capnp.OutPort.new_message()
-        out_port.capnp(capnp_out_port)
-        self.assertEqual(capnp_out_port.name, "")
-        self.assertEqual(dill.loads(capnp_out_port.type), as_delta_type(int))
-
     def test_out_port_capnp_wiring(self):
         """Generate wiring. Should just call same method in destination."""
         in_port = Mock()
-        out_port = OutPort(NamespacedName("node_name", None),
-                           as_delta_type(int), in_port, None)
+        out_port = OutPort(None, as_delta_type(int), in_port, None)
         out_port.capnp_wiring([], None)
         in_port.capnp_wiring.assert_called_with([], None)
 
@@ -236,11 +226,8 @@ class PythonNodeSerialisationTest(unittest.TestCase):
 
     def test_splitter_serialisation(self):
         """Splitter nodes should be added when serialising."""
-        @DeltaBlock(allow_const=False)
-        def add(a: int, b: int) -> int:
-            return a+b
         with DeltaGraph() as test_graph:
-            a = add(2, 3)
+            a = add_non_const(2, 3)
             self.func(a, 4)
             self.func(a, 5)
 
@@ -352,6 +339,37 @@ class PythonNodeSerialisationTest(unittest.TestCase):
                   'r') as file:
             self.assertEqual(g_capnp, json.load(file))
 
+    def test_migen_serialization(self):
+        """Serialize/deserialize a graph with a node with a PyMigenBody.
+
+        Notes
+        -----
+        The content of the bodies depends on the environment, i.e. how the test
+        is executed. For this reason we just compare the structure of the graph
+        here.
+        """
+        DeltaGraph.clean_stack()
+        datapath = os.path.join('deltalanguage', 'test', 'data')
+
+        s = StateSaver(int)
+
+        example_migen = MigenDUT(name='counter',
+                                 vcd_name="/workdir/MigenDUT.vcd")
+
+        with DeltaGraph() as graph:
+            example_migen_out = example_migen.call(40, 2)
+            s.save_and_exit(add_non_const(example_migen_out.out1,
+                                          multiplier(example_migen_out.out2)))
+
+        data, _ = serialize_graph(graph)
+        self.assertEqual(type(data), bytes)
+        g_capnp = deserialize_graph(data).to_dict()
+        assert_capnp_content_types(self, g_capnp)
+
+        with open(os.path.join(datapath, 'graph_with_migen_capnp.json'),
+                  'r') as file:
+            self.assertEqual(g_capnp, json.load(file))
+
     def test_multi_body_serialisation(self):
         """Tests a graph with a multi-body node is serialised and matches
         a target capnp file.
@@ -378,7 +396,7 @@ class PythonNodeSerialisationTest(unittest.TestCase):
         """If a port has type top serialisation should throw an error."""
         s = StateSaver()
         with DeltaGraph() as graph:
-            s.save_and_exit(return_1())
+            s.save_and_exit(return_1_const())
 
         with self.assertRaises(DeltaTypeError):
             serialize_graph(graph)
@@ -391,7 +409,7 @@ class FileSerialisationTest(unittest.TestCase):
         """Set up a simple graph"""
         saver = StateSaver(int)
         with DeltaGraph() as test_graph:
-            saver.save_and_exit(return_1())
+            saver.save_and_exit(return_1_const())
         self.graph = test_graph
 
     def assert_correct_file_serialisation(self, files):
